#version 330 core

// strictly for sand walking, not dungeons

layout(location = 0) in vec3 modelPos;
layout(location = 1) in vec2 modelUV;

out float opacity;
out vec2 UV;

// MVP must match string in glGetUniformLocation(pid,"MVP")
uniform mat4 MVP;
uniform float mytime;
uniform vec3 wPos;
uniform float horiAng;
uniform int direction; //-1=>back, 0=>stop, 1=>forward


const vec3 hRad = vec3(0.015,0.015,0.01); // head dimensions
const vec3 bRad = vec3(0.01,0.02,0.01); // body dimensions
const vec3 aRad = vec3(0.005,0.02,0.005); // arm dimensions
const vec3 lRad = vec3(0.005,0.02,0.005); // leg dimensions
const float fOffz = 0.30; // magnitude of stride



// define a ftn giving zoffsets to feet
float walkingDZ( float tm, int dir ) {
	float x=tm*float(dir);
	float dz = fOffz*sin(x);
	if (dir==0) dz=0.0;
	return dz;
} // end walking


const float onepi = 3.14159;

// avatar is defined as a unit radius cube centered on origin
// made up of 6 rectangular parts :
// Y>0.5 is head
// Y>0.0 is torso
//
// ---------------- bottom layer has 4 parts:
//
// leg leg    ^
// arm arm    |
//            Z
//      <---X
//





void main(){

	vec3 posrot;
	int id;
	float dz;

	float angl = horiAng;
	vec3 pos = modelPos;


	vec3 brad;
	brad.x=bRad.x;
	brad.y=bRad.z;
	brad.z=bRad.y;






// here, we identify body segment

	if (pos.y > 0.5)      id=0; //head
	else if (pos.y > 0.0) id=1; //torso

	else if (pos.z>0.0) //legs
	{
		if (pos.x>0.0) id=2; //left leg
		else           id=3; //right leg
	}

	else  //arms pos.z<0
	{
		if (pos.x>0.0) id=4; //left arm
		else           id=5; //right arm
	}


//////////// begin rotate torso ///////////////////////////////
	if(id==1) {

		pos.y -= 0.25; // Xlate to origin

		pos.x *= bRad.x;
		pos.y *= 4.0*bRad.y;
		pos.z *= bRad.z;
		// now is expanded to proper size

		//swap Y,Z [rotate 90deg forward]
		float sav=pos.y;
		pos.y=-pos.z;
		pos.z=sav;

		vec3 npos = normalize( pos/bRad ); //round toward ellipsoid
		pos = npos*bRad*vec3(1.0,0.8,2.2); //scale to size

		pos.y += brad.y; //lift to body pos

	}
//////////// end rotate torso ///////////////////////////////


	else if (id==0) {             //head

		pos.y -= 0.75; // Xlate to origin

		pos.x *= hRad.x;
		pos.y *= 4.0*hRad.y;
		pos.z *= hRad.z;
		// now is expanded to proper size

		vec3 npos = normalize( pos/hRad ); //round toward ellipsoid
		pos = npos*hRad*vec3(1.0,1.2,1.2); //scale to size

		pos.y += brad.y; //move upward to body top
		pos.z += hRad.z+brad.z; //move forward to body front

	}

	else if (id==3) {            //right leg

		pos.x+=0.5;  pos.y+=0.5; pos.z-=0.5; // Xlate to origin

		pos.x *= 2.0*lRad.x;
		pos.y *= 2.0*lRad.y;
		pos.z *= 2.0*lRad.z;
		// now is expanded to proper size

		vec3 npos = normalize( pos/lRad ); //round toward ellipsoid
		pos = npos*lRad*vec3(1.0,1.0,1.0); //scale to size


		pos.x -= 0.5*brad.x; //rightward
		pos.y -= 0.8*lRad.y; //lower to leg pos
		pos.z -= brad.z; // back to body rear

	}
	else if (id==2) {            // left leg

		pos.x-=0.5;  pos.y+=0.5; pos.z-=0.5; // Xlate to origin

		pos.x *= 2.0*lRad.x;
		pos.y *= 2.0*lRad.y;
		pos.z *= 2.0*lRad.z;
		// now is expanded to proper size

		vec3 npos = normalize( pos/lRad ); //round toward ellipsoid
		pos = npos*lRad*vec3(1.0,1.0,1.0); //scale to size

		pos.x += 0.5*brad.x; //leftward
		pos.y -= 0.8*lRad.y; //lower to leg pos
		pos.z -= brad.z; // back to body rear

	}

	else if (id==5) {            //right arm

		pos.x+=0.5;  pos.y+=0.5; pos.z+=0.5; // Xlate to origin

		pos.x *= 2.0*aRad.x;
		pos.y *= 2.0*aRad.y;
		pos.z *= 2.0*aRad.z;
		// now is expanded to proper size

		vec3 npos = normalize( pos/aRad ); //round toward ellipsoid
		pos = npos*aRad*vec3(1.0,1.5,1.0); //scale to size


		pos.x -= 0.8*brad.x; //rightward to arm pos
		pos.y -= aRad.y; //lower to arm pos
		pos.z += brad.z; // forward to body front

	}
	else if (id==4) {            // left arm

		pos.x-=0.5;  pos.y+=0.5; pos.z+=0.5; // Xlate to origin

		pos.x *= 2.0*aRad.x;
		pos.y *= 2.0*aRad.y;
		pos.z *= 2.0*aRad.z;
		// now is expanded to proper size

		vec3 npos = normalize( pos/aRad ); //round toward ellipsoid
		pos = npos*aRad*vec3(1.0,1.5,1.0); //scale to size


		pos.x += 0.8*brad.x; //leftward to arm pos
		pos.y -= aRad.y; //lower to arm pos
		pos.z += brad.z; // forward to body front

	}







// legs need to walk here, BEFORE rotation
	if ( (id==3 ) ) { //rightleg
		pos.z += pos.y * walkingDZ(7.0*mytime,direction);
	} else if ( (id==2) ) { //leftleg
		pos.z += pos.y * walkingDZ(7.0*mytime+onepi,direction);
	}


// arms need to swing here, BEFORE rotation
	if ( (id==4) ) { // leftarm
		pos.z += pos.y * walkingDZ(7.0*mytime,direction);
	} else if ( (id==5) ) { // rightarm
		pos.z += pos.y * walkingDZ(7.0*mytime+onepi,direction);
	}



	// rotate per horiAng [about Y-axis]
	posrot.y = pos.y;
	posrot.x = +cos(angl)*pos.x + sin(angl)*pos.z;
	posrot.z = -sin(angl)*pos.x + cos(angl)*pos.z;
	// now is rotated to proper look-direction


	// translate into position
	posrot += wPos;

	// put feet on ground
	//posrot.y += -0.02+brad.y+lRad.y;
	posrot.y += 0.01+lRad.y;



	opacity=1.0;

	gl_Position =  MVP * vec4(posrot,1.0);

	UV = modelUV;

}


//--
//-- Copyright (C) 2019  <fastrgv@gmail.com>
//--
//-- This program is free software: you can redistribute it and/or modify
//-- it under the terms of the GNU General Public License as published by
//-- the Free Software Foundation, either version 3 of the License, or
//-- (at your option) any later version.
//--
//-- This program is distributed in the hope that it will be useful,
//-- but WITHOUT ANY WARRANTY; without even the implied warranty of
//-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//-- GNU General Public License for more details.
//--
//-- You may read the full text of the GNU General Public License
//-- at <http://www.gnu.org/licenses/>.
//--

